Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(667)

Unified Diff: ui/base/models/table_model.h

Issue 10437006: Converts ui/views/controls, ui/views/examples, ui/base/models to ImageSkia (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Rebased Created 8 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ui/base/models/table_model.h
diff --git a/ui/base/models/table_model.h b/ui/base/models/table_model.h
index a6dbbb3e59e0e65c372b78154abd942148515aeb..6621999400b086d6109b824d96d0ecbb21c29ec7 100644
--- a/ui/base/models/table_model.h
+++ b/ui/base/models/table_model.h
@@ -12,7 +12,9 @@
#include "ui/base/ui_export.h"
#include "unicode/coll.h"
-class SkBitmap;
+namespace gfx {
+class ImageSkia;
+}
namespace ui {
@@ -39,9 +41,9 @@ class UI_EXPORT TableModel {
// Returns the small icon (16x16) that should be displayed in the first
// column before the text. This is only used when the TableView was created
- // with the ICON_AND_TEXT table type. Returns an isNull() bitmap if there is
- // no bitmap.
- virtual SkBitmap GetIcon(int row);
+ // with the ICON_AND_TEXT table type. Returns an isNull() image if there is
+ // no image.
+ virtual gfx::ImageSkia GetIcon(int row);
// Returns the tooltip, if any, to show for a particular row. If there are
// multiple columns in the row, this will only be shown when hovering over

Powered by Google App Engine
This is Rietveld 408576698